@@ -23,7 +23,7 @@ from collections import ChainMap
 from unicodedata import normalize
 
 __all__ = ["sro2syllabics", "syllabics2sro"]
-__version__ = "2021.4.15"
+__version__ = "2021.7.26"
 
 
 DEFAULT_HYPHENS = "\N{NARROW NO-BREAK SPACE}"
@@ -203,7 +203,7 @@ sro2syllabics_lookup = {
     "ywô": "ᔸ",
     "ywa": "ᔺ",
     "ywâ": "ᔼ",
-    "th": "ᖮ",
+    "th": "ᙾ",
     "thê": "ᖧ",
     "thi": "ᖨ",
     "thî": "ᖩ",
